package xyz.mcutils;

import lombok.SneakyThrows;
import org.junit.jupiter.api.Test;
import xyz.mcutils.exception.ErrorResponse;
import xyz.mcutils.models.cache.CachedBedrockMinecraftServer;
import xyz.mcutils.models.cache.CachedJavaMinecraftServer;
import xyz.mcutils.models.cache.CachedServerBlockedStatus;
import xyz.mcutils.models.cache.CachedServerPreview;
import xyz.mcutils.models.server.CachedServerIcon;
import xyz.mcutils.models.server.ServerPlatform;

public class ServerTests {

    private final String testJavaServer = "play.hypixel.net";
    private final String testBedrockServer = "geo.hivebedrock.network";
    private final String testInvalidServer = "invalidhostnamehahahahahayesslmaooo";

    @Test
    @SneakyThrows
    public void ensureJavaServerLookupSuccess() {
        CachedJavaMinecraftServer server = McUtilsAPI.getJavaServer(testJavaServer);
        assert server.getHostname().equals(testJavaServer);
    }

    @Test
    @SneakyThrows
    public void ensureJavaServerLookupFailure() {
        try {
            McUtilsAPI.getJavaServer(testInvalidServer);
        } catch (ErrorResponse ex) {
            assert ex.getCode() == 400;
        }
    }

    @Test
    @SneakyThrows
    public void ensureJavaServerIconLookupSuccess() {
        CachedServerIcon icon = McUtilsAPI.getServerIcon(testJavaServer);
        assert icon.getBytes() != null;
    }

    @Test
    @SneakyThrows
    public void ensureJavaServerIconLookupFailure() {
        try {
            McUtilsAPI.getServerIcon(testInvalidServer);
        } catch (ErrorResponse ex) {
            assert ex.getCode() == 400;
        }
    }

    @Test
    @SneakyThrows
    public void ensureJavaServerBlockedLookupSuccess() {
        CachedServerBlockedStatus status = McUtilsAPI.getServerBlockedStatus(testJavaServer);
        assert !status.isBlocked();
    }

    @Test
    @SneakyThrows
    public void ensureBedrockServerLookupSuccess() {
        CachedBedrockMinecraftServer server = McUtilsAPI.getBedrockServer(testBedrockServer);
        assert server.getHostname().equals(testBedrockServer);
    }

    @Test
    @SneakyThrows
    public void ensureBedrockServerLookupFailure() {
        try {
            McUtilsAPI.getBedrockServer(testInvalidServer);
        } catch (ErrorResponse ex) {
            assert ex.getCode() == 400;
        }
    }

    @Test
    @SneakyThrows
    public void ensureBedrockServerIconLookupSuccess() {
        CachedServerIcon icon = McUtilsAPI.getServerIcon(testBedrockServer);
        assert icon.getBytes() != null;
    }

    @Test
    @SneakyThrows
    public void ensureBedrockServerIconLookupFailure() {
        try {
            McUtilsAPI.getServerIcon(testInvalidServer);
        } catch (ErrorResponse ex) {
            assert ex.getCode() == 400;
        }
    }

    @Test
    @SneakyThrows
    public void ensureServerPreviewLookupSuccess() {
        CachedServerPreview icon = McUtilsAPI.getServerPreview(ServerPlatform.JAVA, testJavaServer);
        assert icon.getBytes() != null;
    }

    @Test
    @SneakyThrows
    public void ensureServerPreviewLookupFailure() {
        try {
            McUtilsAPI.getServerPreview(ServerPlatform.JAVA, testInvalidServer);
        } catch (ErrorResponse ex) {
            assert ex.getCode() == 400;
        }
    }
}
